@@ -86,6 +86,8 @@ struct _Animation_WallpaperPrivate
     gint yapplet;
     Scene *scene;
     GHashTable * hash_scene_func;
+    GKeyFile *config_file;
+    gint view;
 };
 
 struct _AWallpaperPlugin
