@@ -22,6 +22,9 @@
  * 02110-1301 USA
 */
 /*******************************************************************************/
+#ifndef _livewp_config_h
+#define _livewp_config_h 1
+
 #include "livewp-common.h"
 #include <gconf/gconf-client.h>
 
@@ -30,4 +33,4 @@
 #define GCONF_KEY_RANIMATION                        GCONF_KEY_PREFIX"/rich_animation"
 gint read_config(Animation_WallpaperPrivate *priv); 
 void save_config(Animation_WallpaperPrivate *priv); 
-
+#endif
