@@ -34,7 +34,7 @@ void lw_about(void){
     gtk_window_set_position(GTK_WINDOW(window), GTK_WIN_POS_CENTER);
     gtk_window_set_modal(GTK_WINDOW(window), TRUE);
     vbox = gtk_vbox_new (FALSE, 5);
-    label_about = gtk_label_new (_("Live Wallpaper\n Version 0.5 \n Copyright(c) 2010\n \
+    label_about = gtk_label_new (_("Live Wallpaper\n Version 0.6 \n Copyright(c) 2010\n \
 Tanya Makova\n Vlad Vasiliev\n \
 Copyright(c) 2010 for design themes Berlin and Modern Vasya Bobrikov\n \
 Copyright(c) 2010 for design theme Matrix Andrew Zhilin\n \
@@ -54,8 +54,7 @@ Russian - Tanya Makova \n \
 }
 /*******************************************************************************/
 GtkWidget *
-create_theme_selector (void)
-{
+create_theme_selector (void){
       GtkWidget *selector;
 
       selector = hildon_touch_selector_new_text ();
@@ -66,6 +65,58 @@ create_theme_selector (void)
       return selector;
 }
 /*******************************************************************************/
+void
+theme_button_clicked(GtkButton *button, Animation_WallpaperPrivate *priv){
+
+    lw_theme_settings(priv, button);
+}
+/********************************************************************************/
+void
+set_button_image(GtkWidget * button, gchar *theme, gboolean enable){
+    GtkWidget * image = NULL; 
+    GdkPixbuf * pixbuf = NULL;
+    gchar *str = NULL;
+    if (enable)
+        str = g_strdup_printf( "%s/%s/%s", THEME_PATH, 
+                        theme, "icon.png");
+    else 
+        str = g_strdup_printf( "%s/%s/%s", THEME_PATH, 
+                        theme, "icond.png");
+    pixbuf = gdk_pixbuf_new_from_file_at_size (str, 
+                                             100, 
+                                             60, 
+                                             NULL);
+    if (str)
+        g_free(str);
+    if (pixbuf){
+        image = gtk_image_new_from_pixbuf (pixbuf);
+        g_object_unref(G_OBJECT(pixbuf));
+    }
+
+   hildon_button_set_image (HILDON_BUTTON (button), image);
+}
+/********************************************************************************/
+GtkWidget *
+create_image_button (gint view, DBusConnection *conn_sess){
+    GtkWidget *button;
+    GtkWidget *image;
+    gchar * str;
+    GdkPixbuf * pixbuf;
+    
+    Animation_WallpaperPrivate *priv = g_new0(Animation_WallpaperPrivate, 1);
+    priv->view = view;
+    priv->dbus_conn_session = conn_sess;
+    read_config(priv);
+    button = hildon_button_new(HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT,
+                                    HILDON_BUTTON_ARRANGEMENT_VERTICAL);
+    g_object_set_data(G_OBJECT(button), "view", GINT_TO_POINTER(view));
+    set_button_image(button, priv->theme, check_applet_state(view));
+    g_signal_connect(button, "clicked", G_CALLBACK(theme_button_clicked), priv);
+    hildon_button_set_image_position (HILDON_BUTTON (button), GTK_POS_RIGHT);
+    return button;
+
+}
+/********************************************************************************/
 GtkWidget *
 create_themes_button (gchar *theme){
 
@@ -123,21 +174,76 @@ show_settings(GtkWidget *widget, Animation_WallpaperPrivate *priv){
 }
 /*******************************************************************************/
 void 
-lw_settings(Animation_WallpaperPrivate *priv, gpointer data){
+lw_main_settings(Animation_WallpaperPrivate *priv, gpointer data){
     gint result;
     GtkWidget *window = NULL;
-    GtkWidget *save_button;
-    GtkWidget *theme_button;
-    GtkWidget *enable_button;
-    GtkWidget *rich_animation_button;
+    GtkWidget *theme_button1;
+    GtkWidget *theme_button2;
+    GtkWidget *theme_button3;
+    GtkWidget *theme_button4;
+    GtkWidget *hbox;
 
     window = gtk_dialog_new();
 
     gtk_window_set_title(GTK_WINDOW(window), _("Live Wallpaper Settings"));
     gtk_window_set_position(GTK_WINDOW(window), GTK_WIN_POS_CENTER);
     gtk_window_set_modal(GTK_WINDOW(window), TRUE);
+    /* Create Theme button */
+    hbox = gtk_hbox_new(FALSE, 5);
+    theme_button1 = create_image_button(0, priv->dbus_conn_session);
+    gtk_box_pack_start(GTK_BOX(hbox),
+                                   theme_button1, TRUE, TRUE, 5);
+    theme_button2 = create_image_button(1, priv->dbus_conn_session);
+    gtk_box_pack_start(GTK_BOX(hbox),
+                                   theme_button2, TRUE, TRUE, 5);
+    theme_button3 = create_image_button(2, priv->dbus_conn_session);
+    gtk_box_pack_start(GTK_BOX(hbox),
+                                   theme_button3, TRUE, TRUE, 5);
+    theme_button4 = create_image_button(3, priv->dbus_conn_session);
+    gtk_box_pack_start(GTK_BOX(hbox),
+                                   theme_button4, TRUE, TRUE, 5);
+    gtk_box_pack_start(GTK_BOX(GTK_DIALOG(window)->vbox),
+                                   hbox, TRUE, TRUE, 5);
+
+    gtk_widget_show (theme_button1);
+    gtk_widget_show (theme_button2);
+    gtk_widget_show (theme_button3);
+    gtk_widget_show (theme_button4);
+    gtk_widget_show_all (hbox);
+    gtk_widget_show (window);
+    gtk_dialog_add_button(GTK_DIALOG(window), _("About"), GTK_RESPONSE_NO);
+
+    result = gtk_dialog_run(GTK_DIALOG(window));
+
+    switch(result){
+        case GTK_RESPONSE_NO:
+            gtk_widget_destroy(window);
+            window = NULL;
+            lw_about();
+        break;
+    }
+    if (window)
+        gtk_widget_destroy(window);
+}
+
+/*******************************************************************************/
+void 
+lw_theme_settings(Animation_WallpaperPrivate *priv, GtkWidget *button){
+    gint result;
+    GtkWidget *window = NULL;
+    GtkWidget *save_button;
+    GtkWidget *theme_button;
+    GtkWidget *enable_button;
+    GtkWidget *rich_animation_button;
+    gint view = priv->view;
+
+    window = gtk_dialog_new();
+
+    gtk_window_set_title(GTK_WINDOW(window), _("View Settings"));
+    gtk_window_set_position(GTK_WINDOW(window), GTK_WIN_POS_CENTER);
+    gtk_window_set_modal(GTK_WINDOW(window), TRUE);
     /* Create Enable button */
-    enable_button = create_enable_button(check_applet_state()); 
+    enable_button = create_enable_button(check_applet_state(view)); 
     gtk_box_pack_start(GTK_BOX(GTK_DIALOG(window)->vbox),
                                    enable_button, TRUE, TRUE, 5);
     /* Create Theme button */
@@ -152,8 +258,8 @@ lw_settings(Animation_WallpaperPrivate *priv, gpointer data){
     gtk_widget_show (theme_button);
     gtk_widget_show (rich_animation_button);
     gtk_widget_show (window);
-    gtk_dialog_add_button(GTK_DIALOG(window), _("About"), GTK_RESPONSE_NO);
     save_button = gtk_dialog_add_button(GTK_DIALOG(window), _("Save"), GTK_RESPONSE_YES);
+
     result = gtk_dialog_run(GTK_DIALOG(window));
 
     switch(result){
@@ -174,21 +280,23 @@ lw_settings(Animation_WallpaperPrivate *priv, gpointer data){
                 priv->rich_animation = TRUE;
             else
                 priv->rich_animation = FALSE;
-            /* Save config */
+                        /* Save config */
             save_config(priv);
             /* action with applet */
             if (hildon_check_button_get_active (HILDON_CHECK_BUTTON(enable_button))){
-                    if (!check_applet_state())
-                        start_applet();
-                    else
+                    if (!check_applet_state(view)){
+                        start_applet(view);
+                    }else {
                         send_dbus_signal (priv,
                               LIVEWP_SIGNAL_INTERFACE,
                               LIVEWP_SIGNAL_PATH,
                               LIVEWP_RELOAD_CONFIG);
+                    }
             }else
-                    if (check_applet_state())
-                        stop_applet();
+                    if (check_applet_state(view))
+                        stop_applet(view);
 
+            set_button_image(button, priv->theme, check_applet_state(view));
             break;
         default:
         case GTK_RESPONSE_OK:
@@ -204,44 +312,97 @@ lw_settings(Animation_WallpaperPrivate *priv, gpointer data){
 }
 /*******************************************************************************/
 gboolean
-check_applet_state(void){
-    FILE    *file_in;
-    gchar buffer[2048];
+check_applet_state(gint number){
+
+    HDConfigFile *config_file = NULL;
+    GKeyFile *gkey_file = NULL;
+    gchar *str = NULL;
     gboolean result = FALSE;
+    if (number > 3 || number < 0)
+        return FALSE;
+
+    str = g_strdup_printf("livewp-home-widget.desktop-%i",number);
+    config_file = hd_config_file_new(NULL, "/home/user/.config/hildon-desktop/", "home.plugins");
+    
+    gkey_file = hd_config_file_load_file(config_file, FALSE);
+    if (gkey_file && str){
+        result = g_key_file_has_group(gkey_file, str);
+        g_free(str);
+    }
+    return result;
+#if 0
+    FILE    *file_in = NULL;
+    gchar buffer[2048];
 
     file_in = fopen("/home/user/.config/hildon-desktop/home.plugins","r");
-    while (!feof(file_in)) {
-            memset(buffer, 0, sizeof(buffer));
-            fgets(buffer, sizeof(buffer) - 1, file_in);
-            if (!strcmp(buffer, 
-                        "X-Desktop-File=/usr/share/applications/hildon-home/livewp-home-widget.desktop\n")){
-                result = TRUE;
-                break;
-            }
-   }
-   fclose(file_in);
+    if (file_in){
 
-    return result;
-}
-/*******************************************************************************/
-void
-start_applet(void){
-    FILE    *file_out;
-
-    file_out = fopen("/home/user/.config/hildon-desktop/home.plugins","w+");
-    if (file_out){
-        fputs("\n", file_out);
-        fputs("[livewp-home-widget.desktop-0]\n",file_out);
-        fputs("X-Desktop-File=/usr/share/applications/hildon-home/livewp-home-widget.desktop\n",file_out);
-        fclose(file_out);
+        fprintf(stderr,"Check applet state\n");
+        while (!feof(file_in)) {
+                memset(buffer, 0, sizeof(buffer));
+                fgets(buffer, sizeof(buffer) - 1, file_in);
+                if (!strcmp(buffer, 
+                            "X-Desktop-File=/usr/share/applications/hildon-home/livewp-home-widget.desktop\n")){
+                    result = TRUE;
+                    break;
+                }
+       }
+        fclose(file_in);
     }
+#endif
 }
 /*******************************************************************************/
 void
-stop_applet(void){
+start_applet(gint number){
+
+    HDConfigFile *config_file = NULL;
+    GKeyFile *gkey_file = NULL;
+    gchar *str = NULL;
+
+    if (number > 3 || number < 0)
+        return;
+    str = g_strdup_printf("livewp-home-widget.desktop-%i",number);
+    config_file = hd_config_file_new(NULL, "/home/user/.config/hildon-desktop/", "home.plugins");
+    
+    gkey_file = hd_config_file_load_file(config_file, FALSE);
+    if (gkey_file){
+        g_key_file_set_string (gkey_file, str, "X-Desktop-File", "/usr/share/applications/hildon-home/livewp-home-widget.desktop");
+        hd_config_file_save_file( config_file, gkey_file);
+        g_key_file_free(gkey_file);
+    }else
+        fprintf(stderr, "Problem with config file");
+    if (str)
+        g_free(str);
+    g_object_unref(config_file);
+}
+/*******************************************************************************/
+void
+stop_applet(gint number){
+    HDConfigFile *config_file = NULL;
+    GKeyFile *gkey_file = NULL;
+    gchar *str = NULL;
+
+    if (number > 3 || number < 0)
+        return;
+    str = g_strdup_printf("livewp-home-widget.desktop-%i",number);
+    config_file = hd_config_file_new(NULL, "/home/user/.config/hildon-desktop/", "home.plugins");
+    
+    gkey_file = hd_config_file_load_file(config_file, FALSE);
+    if (gkey_file){
+         g_key_file_remove_group(gkey_file, str, NULL);  
+        hd_config_file_save_file( config_file, gkey_file);
+        g_key_file_free(gkey_file);
+    }else
+        fprintf(stderr, "Problem with config file");
+    if (str)
+        g_free(str);
+    g_object_unref(config_file);
+
+#if 0    
     FILE    *file_in;
     FILE    *file_out;
     gchar buffer[2048];
+    gchar * str = NULL;
 
     file_in = fopen("/home/user/.config/hildon-desktop/home.plugins","r");
     file_out = fopen("/tmp/livewallpaper.plugins","w");
@@ -249,10 +410,14 @@ stop_applet(void){
         while (!feof(file_in)) {
             memset(buffer, 0, sizeof(buffer));
             fgets(buffer, sizeof(buffer) - 1, file_in);
-            if (strcmp(buffer, "[livewp-home-widget.desktop-0]\n") &&
+            str = g_strdup_printf("[livewp-home-widget.desktop-%i]\n", number);
+            if (strcmp(buffer, str) &&
                 strcmp(buffer, "X-Desktop-File=/usr/share/applications/hildon-home/livewp-home-widget.desktop\n"))
                 fputs(buffer, file_out);
         }
+        if (str){
+            g_free(str);
+        }
         fclose(file_out);
         fclose(file_in);
         file_in = fopen("/tmp/livewallpaper.plugins","r");
@@ -268,4 +433,5 @@ stop_applet(void){
             unlink ("/tmp/livewallpaper.plugins");
         }
     }
+#endif
 }
